@@ -58,6 +58,10 @@ public class DomSerializer {
     private static final String CSS_COMMENT_END = "*/";
 
     private static final String NEW_LINE = "\n";
+    
+    private static final String XML_10 = "1.0";
+    
+    private static final String XML_11 = "1.1";
 
     /**
      * The HTML Cleaner properties set by the user to control the HTML cleaning.
@@ -73,7 +77,21 @@ public class DomSerializer {
     
     protected boolean strictErrorChecking = true;
     
-    /**
+    protected String xmlVersion = XML_10;
+    
+    public String getXmlVersion() {
+		return xmlVersion;
+	}
+
+	public void setXmlVersion(String xmlVersion) throws Exception {
+		if (xmlVersion == XML_10 || xmlVersion == XML_11) {
+			this.xmlVersion = xmlVersion;
+		} else {
+			throw new Exception("Invalid XML version - must be 1.0 or 1.1");
+		}
+	}
+
+	/**
      * @param props the HTML Cleaner properties set by the user to control the HTML cleaning.
      * @param escapeXml if true then escape XML entities
      * @param deserializeCdataEntities if true then deserialize entities in CData sections
@@ -113,6 +131,7 @@ public class DomSerializer {
         this(props, true);
     }
     
+    
     //
     // Allow overriding of serialization for implementations. See bug #167.
     //
@@ -147,8 +166,10 @@ public class DomSerializer {
             //
             if (qualifiedName.equals("HTML")) qualifiedName = "html";
             document = impl.createDocument(rootNode.getNamespaceURIOnPath(""), qualifiedName, documentType);
+            document.setXmlVersion(xmlVersion);
         } else {
         	document = builder.newDocument();
+        	document.setXmlVersion(xmlVersion);
         	Element rootElement = document.createElement(rootNode.getName());
         	document.appendChild(rootElement);
         }
