@@ -59,7 +59,7 @@ public class Html5TagProvider implements ITagInfoProvider {
 	 * Phrasing tags are those that can make up paragraphs along with text to
 	 * make Phrasing Content. Generally speaking, phrasing content only allows phrasing content as child tags.
 	 */
-	private static final String PHRASING_TAGS = "a,abbr,area,audio,b,bdi,bdo,br,button,canvas,cite,code,command,datalist,del,dfn,em,i,input,ins,kbd,keygen,label,link,map,mark,meta,meter,noscript,output,progress,p,ruby,samp,s,script,select,small,span,strong,sub,sup,template,textarea,time,u,var,wbr";
+	private static final String PHRASING_TAGS = "a,abbr,area,audio,b,bdi,bdo,br,button,canvas,cite,code,command,datalist,del,dfn,em,i,input,ins,kbd,keygen,label,link,map,mark,meta,meter,noscript,output,progress,p,ruby,samp,s,script,select,small,span,strong,sub,sup,svg,template,textarea,time,u,var,wbr";
 
 	/**
 	 * Most elements that are used in the body of documents and applications are categorized as flow content.
@@ -96,8 +96,6 @@ public class Html5TagProvider implements ITagInfoProvider {
 		tagInfo = new TagInfo("svg", ContentType.all, BelongsTo.BODY, false,
 				false, false, CloseTag.required, Display.block);
 		tagInfo.defineAllowedChildrenTags("animate,animateMotion,animateTransform,discard,set,desc,title,metadata,linearGradient,radialGradient,pattern,circle,ellipse,line,path,polygon,polyline,rect,defs,g,svg,symbol,use,a,audio,canvas,clipPath,filter,foreignObject,iframe,image,marker,mask,script,style,switch,text,video,view");
-		tagInfo.defineCloseBeforeCopyInsideTags(CLOSE_BEFORE_COPY_INSIDE_TAGS);
-		tagInfo.defineCloseBeforeTags(CLOSE_BEFORE_TAGS);
 		tagInfo.setAssumedNamespace("http://www.w3.org/2000/svg");
 		tagInfo.setAssumedNamespacePrefix("svg");
 		this.put("svg", tagInfo);
@@ -830,9 +828,8 @@ public class Html5TagProvider implements ITagInfoProvider {
 				true, false, CloseTag.required, Display.none);
 		this.put("title", tagInfo);
 
-		// As of HTML5, style can be used in <body> where it has an @scoped attribute
-		// TODO add attribute rules
-		tagInfo = new TagInfo("style", ContentType.text, BelongsTo.HEAD_AND_BODY, false,
+		// Current specification: style can only be used in <head>
+		tagInfo = new TagInfo("style", ContentType.text, BelongsTo.HEAD, false,
 				false, false, CloseTag.required, Display.none);
 		this.put("style", tagInfo);
 
