@@ -216,8 +216,8 @@ public class HtmlCleaner {
 	 * HTML encoding is resolved following the attempts in the sequence:
 	 * 1. reading Content-Type response header, 2. Analyzing META tags at the
 	 * beginning of the html, 3. Using platform's default charset.
-	 * @param url
-	 * @return
+	 * @param url the url to retrieve content from
+	 * @return the cleaned content
 	 * @throws IOException
 	 */
 	@Deprecated // Removing network I/O will make htmlcleaner better suited to a server environment which needs managed connections
@@ -295,7 +295,7 @@ public class HtmlCleaner {
 		// Some transitions on resulting html require us to have the tag tree structure.
 		// i.e. if we want to clear insignificant <br> tags. Thus this place is best for
 		// marking nodes to be pruned.
-		while(markNodesToPrune(nodeList, cleanTimeValues)) {
+		while(markNodesToPrune(nodeList, cleanTimeValues, 0)) {
 			if (Thread.currentThread().isInterrupted()) {
 				handleInterruption();
 				return null;
@@ -324,7 +324,10 @@ public class HtmlCleaner {
 		return cleanTimeValues.rootNode;
 	}
 
-	private boolean markNodesToPrune(List nodeList, CleanTimeValues cleanTimeValues) {
+	private boolean markNodesToPrune(List nodeList, CleanTimeValues cleanTimeValues, int depth) {
+		if (depth > properties.getMaxDepth()) {
+			return false;
+		}
 		boolean nodesPruned = false;
 		for (Object next :nodeList) {
 			if(next instanceof TagNode && !cleanTimeValues.pruneNodeSet.contains(next)){
@@ -332,7 +335,7 @@ public class HtmlCleaner {
 				if(addIfNeededToPruneSet(node, cleanTimeValues)) {
 					nodesPruned = true;
 				} else if (!node.isEmpty()){
-					nodesPruned |= markNodesToPrune(node.getAllChildren(), cleanTimeValues);
+					nodesPruned |= markNodesToPrune(node.getAllChildren(), cleanTimeValues, depth+1);
 				}
 			}
 		}
