@@ -849,6 +849,18 @@ public class HtmlTokenizer {
 
     private void comment() throws IOException {
     	go(4);
+
+        // Ignore abruptly closed comments, see https://html.spec.whatwg.org/#parse-error-abrupt-closing-of-empty-comment
+        if ( startsWith(">") ) {
+            go();
+            return;
+        }
+
+        if ( startsWith("->") ) {
+            go(2);
+            return;
+        }
+        
         while ( !isAllRead() && !startsWith("-->") ) {
             saveCurrent();
             go();
