@@ -100,7 +100,15 @@ public abstract class AbstractHtmlCleanerTest {
 	    TransformerFactory tf = TransformerFactory.newInstance();
 	    Transformer transformer = tf.newTransformer();
 	    transformer.transform(new DOMSource(document), new StreamResult(writer));
-	    String actual = writer.getBuffer().toString();
+		String rawActual = writer.getBuffer().toString();
+
+		String[] lines = rawActual.split("\n");
+		StringWriter buffer = new StringWriter();
+		for (String line : lines) {
+			buffer.write(line.trim());
+			buffer.write("\n");
+		}
+		String actual = buffer.toString();
 	    actual = actual.substring(actual.indexOf("<body>\n")+7, actual.indexOf("</body>")).trim();
 	    assertEquals(expected, actual);
 	    cleaner.getProperties().setOmitHtmlEnvelope(true);
@@ -141,6 +149,14 @@ public abstract class AbstractHtmlCleanerTest {
     	
         Assert.assertEquals(HEADER_FULL + expected + FOOTER, actual);
     }
+
+	protected void assertHTMLWithHeader(String expected, String input) throws IOException {
+		StringWriter writer = new StringWriter();
+		serializer.write(cleaner.clean(input), writer, "UTF-8");
+		String actual = writer.toString();
+
+		Assert.assertEquals(HEADER + expected, actual);
+	}
     
     protected void assertHTMLUsingDomSerializer(String expected, String input) throws IOException, ParserConfigurationException {
         DomSerializer ser = new DomSerializer(cleaner.getProperties());
@@ -165,6 +181,17 @@ public abstract class AbstractHtmlCleanerTest {
     	
         Assert.assertEquals(HEADER_FULL + expected + FOOTER + "\n", actual);
     }
+
+	protected void assertHTMLIncludingHeaderUsingJDomSerializer(String expected, String input) throws IOException, ParserConfigurationException {
+		JDomSerializer ser = new JDomSerializer(cleaner.getProperties());
+
+		org.jdom2.Document document = ser.createJDom(cleaner.clean(input));
+
+		XMLOutputter outputter = new XMLOutputter(Format.getRawFormat().setEncoding("UTF-8").setLineSeparator("\n"));
+		String actual = outputter.outputString(document);
+
+		Assert.assertEquals(HEADER + expected + "\n", actual);
+	}
     
     protected String documentToString(
     	    final Document doc)
