@@ -218,7 +218,8 @@ public class CDATATest extends AbstractHtmlCleanerTest {
         assertHTML("<script type=\"text/javascript\">/*<![CDATA[*/\nalert(\"Hello World\")\n/*]]>*/</script>", 
         		"<script type=\"text/javascript\"><![CDATA[\nalert(\"Hello World\")\n]]></script>");
 
-        assertHTML("<style type=\"text/css\">/*<![CDATA[*/\na { color: red; }\n/*]]>*/</style>", 
+        assertHTMLWithHeader(
+				"<html><head><style type=\"text/css\">/*<![CDATA[*/\na { color: red; }\n/*]]>*/</style></head><body /></html>",
         		"<style type=\"text/css\"><![CDATA[\na { color: red; }\n]]></style>");
 
 
@@ -261,7 +262,7 @@ public class CDATATest extends AbstractHtmlCleanerTest {
     }
     
     @Test
-    public void scriptAndCDataDom() throws IOException, ParserConfigurationException
+    public void scriptAndCDataDom() throws IOException, ParserConfigurationException, Exception
     {
 
         CleanerProperties cleanerProperties = new CleanerProperties();
@@ -281,9 +282,10 @@ public class CDATATest extends AbstractHtmlCleanerTest {
         assertHTMLUsingDomSerializer("<script type=\"text/javascript\">/*<![CDATA[*/\nalert(\"Hello World\")\n/*]]>*/</script>", 
         		"<script type=\"text/javascript\"><![CDATA[\nalert(\"Hello World\")\n]]></script>");
 
-        assertHTMLUsingDomSerializer("<style type=\"text/css\">/*<![CDATA[*/\na { color: red; }\n/*]]>*/</style>", 
-        		"<style type=\"text/css\"><![CDATA[\na { color: red; }\n]]></style>");
-
+		assertHTMLIncludingHeaderUsingJDomSerializer(
+				"<html><head><style type=\"text/css\">/*<![CDATA[*/\na { color: red; }\n/*]]>*/</style></head><body /></html>",
+				"<html><head><style type=\"text/css\"><![CDATA[\na { color: red; }\n]]></style></head></html>"
+		);
 
         assertHTMLUsingDomSerializer("<script type=\"text/javascript\">/*<![CDATA[*/\n// Comment \nalert(\"Hello World\")\n //\n/*]]>*/</script>",
         "<script type=\"text/javascript\">// Comment \nalert(\"Hello World\")\n //\n</script>");
@@ -344,7 +346,7 @@ public class CDATATest extends AbstractHtmlCleanerTest {
         assertHTMLUsingJDomSerializer("<script type=\"text/javascript\">/*<![CDATA[*/\nalert(\"Hello World\")\n/*]]>*/</script>", 
         		"<script type=\"text/javascript\"><![CDATA[\nalert(\"Hello World\")\n]]></script>");
 
-        assertHTMLUsingJDomSerializer("<style type=\"text/css\">/*<![CDATA[*/\na { color: red; }\n/*]]>*/</style>", 
+		assertHTMLIncludingHeaderUsingJDomSerializer("<html><head><style type=\"text/css\">/*<![CDATA[*/\na { color: red; }\n/*]]>*/</style></head><body /></html>",
         		"<style type=\"text/css\"><![CDATA[\na { color: red; }\n]]></style>");
 
 
