@@ -60,6 +60,40 @@ public class DomSerializerTest extends AbstractHtmlCleanerTest {
         assertEquals("&lt;^-^&gt;", doc.getElementsByTagName("p").item(0).getChildNodes().item(0).getTextContent());
 	}
 	
+	@Test
+	public void attributeCharacters() throws Exception{
+	    String html="<p dispariție='dispariție.'></p>";
+	    final TagNode tagNode = new HtmlCleaner().clean(html);
+        final CleanerProperties cleanerProperties = new CleanerProperties();
+        cleanerProperties.setAllowInvalidAttributeNames(false);
+        DomSerializer ser = new DomSerializer(cleanerProperties);
+        ser.setXmlVersion("1.1");
+        final Document doc = ser.createDOM(tagNode);
+        assertEquals("dispariție.", doc.getElementsByTagName("p").item(0).getAttributes().item(0).getTextContent());
+	}
+	
+	@Test
+	public void attributeCharactersEncoded() throws Exception{
+	    String html="<p dispari\u021bie='dispari\u021bie.'></p>";
+	    final TagNode tagNode = new HtmlCleaner().clean(html);
+        final CleanerProperties cleanerProperties = new CleanerProperties();
+        cleanerProperties.setAllowInvalidAttributeNames(false);
+        DomSerializer ser = new DomSerializer(cleanerProperties);
+        ser.setXmlVersion("1.1");
+        final Document doc = ser.createDOM(tagNode);
+        assertEquals("dispariție.", doc.getElementsByTagName("p").item(0).getAttributes().item(0).getTextContent());
+	}
+	
+	@Test
+	public void attributeCharacters2() throws Exception{
+	    String html="<p t%st='dispariție.'></p>";
+	    final TagNode tagNode = new HtmlCleaner().clean(html);
+        final CleanerProperties cleanerProperties = new CleanerProperties();
+        cleanerProperties.setAllowInvalidAttributeNames(false);
+        final Document doc = new DomSerializer(cleanerProperties).createDOM(tagNode);
+        assertEquals("dispariție.", doc.getElementsByTagName("p").item(0).getAttributes().item(0).getTextContent());
+	}
+	
 	// See bug #203
 	@Test
 	public void parse2() throws Exception
