@@ -20,6 +20,43 @@ import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
 public class HtmlCleanerTest extends AbstractHtmlCleanerTest {
+
+	// Test for bug #230. Thanks to Simon Urli for the report.
+	@Test
+	public void cleanDl() throws Exception
+	{
+		CleanerProperties cleanerProperties = new CleanerProperties();
+
+		cleanerProperties.setHtmlVersion(5);
+
+		HtmlCleaner cleaner = new HtmlCleaner(cleanerProperties);
+		TagNode tagNode = cleaner.clean("<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE html>\n"
+				+ "<html><body>"
+				+ "<dl>"
+				+ "<div>"
+				+ "<dt>Foo</dt>"
+				+ "<dd>bar</dt>"
+				+ "</div>"
+				+ "</dl>"
+				+ "</body></html>");
+		List<? extends TagNode> dlList = tagNode.getElementListByName("dl", true);
+		assertEquals(1, dlList.size());
+
+		List<? extends TagNode> divList = dlList.get(0).getElementListByName("div", true);
+
+		// assertion failure when using Html5
+		assertEquals(1, divList.size());
+	}
+
+
+	// Test for bug 234. Thanks to Michael Hamann for contributing the test case
+	@Test
+	public void closeComments() throws Exception
+	{
+		cleaner.getProperties().setOmitHtmlEnvelope(true);
+		assertCleanedHtml("<!--> <A href='#'>not a comment", " <a href=\"#\">not a comment</a>");
+		assertCleanedHtml("<!---> <A href='#'>not a comment", " <a href=\"#\">not a comment</a>");
+	}
 	
 	// Test for bug 221. Thanks to Simon Urli for contributing the test case.
 	@Test
@@ -1011,10 +1048,11 @@ public class HtmlCleanerTest extends AbstractHtmlCleanerTest {
     }
     
 	/**
-	 * Test for bug #156
+	 * Test for bug #156. The behaviour has now changed and style tags are no longer
+	 * permitted in BODY so this test is now ignored
 	 * @throws IOException
 	 */
-	@Test
+	@Ignore
 	public void testStyleIsNotRemoved() throws IOException{
 		final String original = "<div><style type=\"text/css\">h1 {color:black;}</style>42</div>";
 		final String expected = "<div><style type=\"text/css\">h1 {color:black;}</style>42</div>";
