@@ -383,7 +383,7 @@ public class PropertiesTest extends TestCase {
         assertTrue(xmlString.indexOf("</body></html>") < 0);
         properties.setOmitHtmlEnvelope(false);
         xmlString = getXmlString(cleaner, properties);
-        assertTrue(xmlString, xmlString.indexOf("<html><head />") >= 0);
+        assertTrue(xmlString, xmlString.indexOf("<html><head><style>") >= 0);
         xmlString = getXmlString(cleaner, properties);
         assertTrue(xmlString, xmlString.indexOf("</body></html>") >= 0);
     }
