@@ -40,6 +40,25 @@ import org.junit.Ignore;
 import org.junit.Test;
 
 public class SVGTest extends AbstractHtmlCleanerTest{
+
+	@Test
+	public void svgTreatedAsPhrasing() throws IOException
+	{
+		CleanerProperties cleanerProperties = new CleanerProperties();
+		cleanerProperties.setOmitXmlDeclaration(false);
+		cleanerProperties.setOmitDoctypeDeclaration(false);
+		cleanerProperties.setIgnoreQuestAndExclam(false);
+		cleanerProperties.setAddNewlineToHeadAndBody(false);
+		cleanerProperties.setUseCdataFor("script,style,altscript");
+		this.cleaner = new HtmlCleaner(cleanerProperties);
+		this.serializer = new SimpleXmlSerializer(cleaner.getProperties());
+
+		assertHTML(
+				"<p><svg xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"><circle cx=\"100\" cy=\"50\" fill=\"red\" r=\"40\" stroke=\"black\" stroke-width=\"2\" /></svg></p>",
+		"<p><svg xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"><circle cx=\"100\" cy=\"50\" fill=\"red\" r=\"40\" stroke=\"black\" stroke-width=\"2\"></circle></svg></p>"
+
+		);
+	}
 	
 	@Test 
 	public void nestedSVG()
